==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/visualisers/AxisTickLabel.cc <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file AxisTickLabel.cc
    \brief Implementation of the Template class AxisTickLabel.
    
    Magics Team - ECMWF 2005
    
    Started: Fri 7-Oct-2005
    
    Changes:
    
*/



#include "AxisTickLabel.h"
#include "PaperPoint.h"
#include "Text.h"
#include "MagicsFormat.h"
#include "Transformation.h"

using namespace magics;

AxisTickLabel::AxisTickLabel() 
{
}


AxisTickLabel::~AxisTickLabel() 
{
}

/*!
 Class information are given to the output-stream.
*/		
void AxisTickLabel::print(ostream& out)  const
{
	out << "AxisTickLabel[";
	out << "]";
}

void AxisTickLabel::horizontal(const AxisItems& ticks,const Colour& colour, HorizontalAxisVisitor& axis)
{
	Justification justification =  axis.justificationTickLabel();
	const Transformation& transformation = axis.transformation();
	
	int count = -1;

	for (AxisItems::const_iterator x = ticks.begin(); x != ticks.end(); ++x)
	{
		if ( !transformation.inX((*x)->position()) ) continue;

        	if ( (*x)->isFirst() && !first_ ) continue;
        	if ( (*x)->isLast() && !last_ ) continue;
          if ( (*x)->label(*type_).empty() ) continue;
        	 count++;
        	if ( count % frequency_  ) continue;

		double pos = axis.offsetTickLabel(height_, (*x)->level());
		
		PaperPoint point(transformation.x((*x)->position()), pos);
		
		if ( magCompare(position_, "inter_tick") ) {
			AxisItems::const_iterator next = x;
			if (++next != ticks.end() ) {
				double x1 = transformation.x((*x)->position());
				double x2 = transformation.x((*next)->position());
				point = PaperPoint((x2+x1)/2, pos);
				if ( !transformation.in(point)) 
				        				return;
			}
			else 
				return; // No more tick to write
				
		}
		
		Text* text = new Text();
		
		Colour newcolour;
		if ((*x)->colour() != "undef" ) 
			newcolour =  Colour((*x)->colour());
		else 
			newcolour =  (colour_->automatic()) ? colour : *colour_;
		
		MagFont font(quality_);
		font.colour(newcolour);
		
	    font.size( ((*x)->height() == double_MIN || (*x)->height() == 0) ? height_ : (*x)->height() );
	   
	    text->addText((*x)->label(*type_), font);	
	    text->setJustification(justification);
	    text->setVerticalAlign(MTOP);

	    text->push_back(point);
	    axis.push_back(text);
	 }
}




void AxisTickLabel::vertical(const AxisItems& ticks,const Colour& colour, VerticalAxisVisitor& axis)
{
	double angle = axis.angleTickLabel();
	Justification justification =  axis.justificationTickLabel();
	const Transformation& transformation = axis.transformation();
	
	int count = -1;

	for (AxisItems::const_iterator y = ticks.begin(); y != ticks.end(); ++y)
	{
		if ( !transformation.inY((*y)->position()) ) continue;

		if ( (*y)->isFirst()   && !first_ ) continue;
		if ( (*y)->isLast() && !last_ ) continue;
		    if ( (*y)->label(*type_).empty() ) continue;

		count++;
		if ( count % frequency_  ) continue;


		Text* text = new Text();

		double pos =  axis.offsetTickLabel(height_, (*y)->level());


		(*text).setAngle(angle);

		text->setJustification(justification);

		PaperPoint point(pos, transformation.y((*y)->position()));

		if ( magCompare(position_, "inter_tick") ) {
			AxisItems::const_iterator next = y;
			if (++next != ticks.end() ) {
        			double y1 = transformation.y((*y)->position());
        			double y2 = transformation.y((*next)->position());
        			point = PaperPoint(pos, y1+(y2+y1)/2);
        			if ( !transformation.in(point)) 
        				return;
			}
			else 
        			return; // No more tick to write
		}

		Colour newcolour =  (colour_->automatic()) ? colour : *colour_;

		MagFont font(quality_);
		font.colour(newcolour);
		
		font.size( ((*y)->height() == double_MIN || (*y)->height() == 0 ) ? height_ : (*y)->height() );

		text->addText((*y)->label(*type_), font);   
		text->setJustification(justification);
		text->setVerticalAlign(MHALF);

		text->push_back(point);
		axis.push_back(text);
	}
}

==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/visualisers/AxisTickLabel.cc <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file AxisTickLabel.cc
    \brief Implementation of the Template class AxisTickLabel.
    
    Magics Team - ECMWF 2005
    
    Started: Fri 7-Oct-2005
    
    Changes:
    
*/



#include "AxisTickLabel.h"
#include "PaperPoint.h"
#include "Text.h"
#include "MagicsFormat.h"
#include "Transformation.h"

using namespace magics;

AxisTickLabel::AxisTickLabel() 
{
}


AxisTickLabel::~AxisTickLabel() 
{
}

/*!
 Class information are given to the output-stream.
*/		
void AxisTickLabel::print(ostream& out)  const
{
	out << "AxisTickLabel[";
	out << "]";
}

void AxisTickLabel::horizontal(const AxisItems& ticks,const Colour& colour, HorizontalAxisVisitor& axis)
{
	Justification justification =  axis.justificationTickLabel();
	const Transformation& transformation = axis.transformation();
	
	int count = -1;

	for (AxisItems::const_iterator x = ticks.begin(); x != ticks.end(); ++x)
	{
		if ( !transformation.inX((*x)->position()) ) continue;

        	if ( (*x)->isFirst() && !first_ ) continue;
        	if ( (*x)->isLast() && !last_ ) continue;
        	string label = (*x)->label(*type_);
          if ( label.empty() ) continue;
        	 count++;
        	if ( count % frequency_  ) continue;

		double pos = axis.offsetTickLabel(height_, (*x)->level());
		
		PaperPoint point(transformation.x((*x)->position()), pos);
		
		if ( magCompare(position_, "inter_tick") ) {
			AxisItems::const_iterator next = x;
			if (++next != ticks.end() ) {
				double x1 = transformation.x((*x)->position());
				double x2 = transformation.x((*next)->position());
				point = PaperPoint((x2+x1)/2, pos);
				if ( !transformation.in(point)) 
				        				return;
			}
			else 
				return; // No more tick to write
				
		}
		
		Text* text = new Text();
		
		Colour newcolour;
		if ((*x)->colour() != "undef" ) 
			newcolour =  Colour((*x)->colour());
		else 
			newcolour =  (colour_->automatic()) ? colour : *colour_;
		
		MagFont font(quality_);
		font.colour(newcolour);
		
	    font.size( ((*x)->height() == double_MIN || (*x)->height() == 0) ? height_ : (*x)->height() );
	   
	    text->addText(label, font);	
	    text->setJustification(justification);
	    text->setVerticalAlign(MTOP);

	    text->push_back(point);
	    axis.push_back(text);
	 }
}




void AxisTickLabel::vertical(const AxisItems& ticks,const Colour& colour, VerticalAxisVisitor& axis)
{
	double angle = axis.angleTickLabel();
	Justification justification =  axis.justificationTickLabel();
	const Transformation& transformation = axis.transformation();
	
	int count = -1;

	for (AxisItems::const_iterator y = ticks.begin(); y != ticks.end(); ++y)
	{
		if ( !transformation.inY((*y)->position()) ) continue;

		if ( (*y)->isFirst()   && !first_ ) continue;
		if ( (*y)->isLast() && !last_ ) continue;
		string label = (*y)->label(*type_);
		    if ( label.empty() ) continue;

		count++;
		if ( count % frequency_  ) continue;


		Text* text = new Text();

		double pos =  axis.offsetTickLabel(height_, (*y)->level());


		(*text).setAngle(angle);

		text->setJustification(justification);

		PaperPoint point(pos, transformation.y((*y)->position()));

		if ( magCompare(position_, "inter_tick") ) {
			AxisItems::const_iterator next = y;
			if (++next != ticks.end() ) {
        			double y1 = transformation.y((*y)->position());
        			double y2 = transformation.y((*next)->position());
        			point = PaperPoint(pos, (y2+y1)/2);
        			if ( !transformation.in(point)) 
        				return;
			}
			else 
        			return; // No more tick to write
		}

		Colour newcolour =  (colour_->automatic()) ? colour : *colour_;

		MagFont font(quality_);
		font.colour(newcolour);
		
		font.size( ((*y)->height() == double_MIN || (*y)->height() == 0 ) ? height_ : (*y)->height() );

		text->addText(label, font);   
		text->setJustification(justification);
		text->setVerticalAlign(MHALF);

		text->push_back(point);
		axis.push_back(text);
	}
}
